@@ -2,13 +2,18 @@ from cement.utils import test
 from common import VersionsFile
 from common.testutils import decallmethods
 from common.update_api import GH, UW
-from common.update_api import github_tags_newer, github_repo, _github_normalize
+from common.update_api import github_tags_newer, github_repo, _github_normalize, \
+    file_mtime, modules_get
 from common.update_api import GitRepo
-from mock import patch, MagicMock, mock_open
+from datetime import datetime, timedelta
+from mock import patch, MagicMock, mock_open, Mock
 from plugins.drupal import Drupal
+from plugins.silverstripe import SilverStripe
 from plugins.update import Update
 from tests import BaseTest
+import codecs
 import common
+import json
 import responses
 
 @decallmethods(responses.activate)
@@ -60,6 +65,10 @@ class UpdateTests(BaseTest):
         responses.add(responses.GET, 'https://github.com/drupal/drupal/releases', body=gh_resp)
         responses.add(responses.GET, 'https://github.com/silverstripe/silverstripe-framework/releases')
 
+    def mock_update_all(self):
+        self.updater.update_version = Mock(spec=self.updater.update_version)
+        self.updater.update_plugins = Mock(spec=self.updater.update_plugins)
+
     def test_update_checks_and_updates(self):
         self.gh_mock()
         self.mock_controller('drupal', 'update_version_check', return_value=True)
@@ -67,7 +76,7 @@ class UpdateTests(BaseTest):
 
         o = mock_open()
         with patch('plugins.update.open', o, create=True):
-            self.updater.update()
+            self.updater.update_version(self.controller_get('drupal')(), "Drupal")
 
         assert m.called
 
@@ -78,7 +87,7 @@ class UpdateTests(BaseTest):
 
         o = mock_open()
         with patch('plugins.update.open', o, create=True):
-            self.updater.update()
+            self.updater.update_version(self.controller_get('drupal')(), "Drupal")
 
         assert not m.called
 
@@ -229,7 +238,7 @@ class UpdateTests(BaseTest):
 
             args, kwargs = m.call_args
             assert isinstance(args[0], VersionsFile)
-            assert args[1] == self.scanner._update_majors
+            assert args[1] == self.scanner.update_majors
 
     def test_drupal_calls_hashes_get(self):
         vf = MagicMock()
@@ -255,7 +264,7 @@ class UpdateTests(BaseTest):
                     assert len(hg.call_args_list) == 2
                     for args, kwargs in hgcl:
                         assert args[0] == vf
-                        assert args[1] == self.scanner._update_majors
+                        assert args[1] == self.scanner.update_majors
 
         version = '7.34'
         expected = tuple([['git', 'checkout', version]])
@@ -272,7 +281,7 @@ class UpdateTests(BaseTest):
 
         with patch('common.update_api.VersionsFile') as vf:
             vf.files_get_all.return_value = files
-            self.gr.hashes_get(vf, self.scanner._update_majors)
+            self.gr.hashes_get(vf, self.scanner.update_majors)
 
             assert vf.files_get_all.called
             assert len(self.mock_md5_file.call_args_list) == len(files)
@@ -346,7 +355,7 @@ class UpdateTests(BaseTest):
             uvc = self.mock_controller('drupal', 'update_version_check', return_value=True)
             uv = self.mock_controller('drupal', 'update_version', return_value=vf)
 
-            self.updater.update()
+            self.updater.update_version(self.controller_get('drupal')(), "Drupal")
 
             args, kwargs = o.call_args
             assert args[0] == self.scanner.versions_file
@@ -362,10 +371,171 @@ class UpdateTests(BaseTest):
         o = mock_open()
         with patch('plugins.update.open', o, create=True):
             with patch('plugins.update.Update.is_valid', return_value=False) as iv:
-                self.updater.update()
+                self.updater.update_version(self.controller_get('drupal')(), "Drupal")
 
                 args, kwargs = iv.call_args
 
                 assert iv.called
                 assert not o().write.called
 
+    def test_plugins_update_check(self):
+        drupal = Drupal()
+        drupal.update_plugins = up = Mock(spec=self.scanner.update_plugins,
+                return_value=([], []))
+
+        today = datetime.today()
+        yesterday = datetime.today() - timedelta(days=1)
+        too_long_ago = today - timedelta(days=400)
+
+        o = mock_open()
+        with patch('plugins.update.open', o, create=True):
+            with patch('common.update_api.file_mtime', return_value=yesterday):
+                self.updater.update_plugins(self.controller_get('drupal')(), 'Drupal')
+                assert not up.called
+
+            with patch('common.update_api.file_mtime', return_value=too_long_ago):
+                self.updater.update_plugins(drupal, 'Drupal')
+                assert up.called
+
+    @test.raises(IOError)
+    def test_file_mtime_raises(self):
+        filename = "filename"
+        with patch('os.path.isfile', return_value=False):
+            file_mtime(filename)
+
+    def test_file_mtime(self):
+        filename = "filename"
+        timestamp = "1424298106"
+        self.mock_check_output.return_value = timestamp
+        dt = datetime.fromtimestamp(int(timestamp))
+
+        with patch('os.path.isfile', return_value=True):
+            rdt = file_mtime(filename)
+
+        assert dt == rdt
+
+    def test_drupal_calls_modules_get(self):
+        o = mock_open()
+        with patch('plugins.update.open', o, create=True):
+            with patch('common.update_api.modules_get') as p:
+                self.updater.update_plugins(self.scanner, "Drupal")
+                assert p.called
+
+    def test_modules_get(self):
+        url = 'https://drupal.org/project/project_module?page=%s'
+        css = '.node-project-module > h2 > a'
+        per_page = 25
+
+        do_resp = codecs.open('tests/resources/drupal_org_response.html',
+                encoding='utf-8').read()
+        do_resp_last = codecs.open('tests/resources/drupal_org_response_partial.html').read()
+        responses.add(responses.GET, 'https://drupal.org/project/project_module?page=0',
+                body=do_resp, match_querystring=True)
+        responses.add(responses.GET, 'https://drupal.org/project/project_module?page=1',
+                body=do_resp, match_querystring=True)
+        responses.add(responses.GET, 'https://drupal.org/project/project_module?page=2',
+                body=do_resp_last, match_querystring=True)
+
+        plugins = []
+        for plugin in modules_get(url, per_page, css):
+            plugins.append(plugin)
+
+        assert len(plugins) == 69
+
+    def test_drupal_update_plugins(self):
+        ret_val = [
+            {"href": "/project/module_1"},
+            {"href": "/project/module_2"},
+            {"href": "/project/module_3"},
+        ]
+
+        results = [
+            'module_1',
+            'module_2',
+            'module_3'
+        ]
+
+        m = mock_open()
+        with patch('common.update_api.modules_get', return_value=ret_val) as mg:
+            plugins, themes = self.scanner.update_plugins()
+
+            assert plugins == results
+            assert themes == results
+
+            assert len(mg.call_args_list) == 2
+            assert mg.call_args_list[0][0][0] != mg.call_args_list[1][0][0]
+
+    def test_drupal_plugins_updates_file(self):
+        plugins = ['plugin_1', 'plugin_2', 'plugin_3']
+        themes = ['theme_1', 'theme_2', 'theme_3']
+
+        self.scanner.update_plugins = Mock(spec=self.scanner.update_plugins,
+                return_value=(plugins, themes))
+
+        m = mock_open()
+        with patch('plugins.update.open', m, create=True) as o:
+            self.updater.update_plugins(self.scanner, "Drupal")
+
+            assert self.scanner.update_plugins.called == True
+            assert len(o.call_args_list) == 2
+
+            for i, call in enumerate(o().write.call_args_list):
+                if i < 3:
+                    check_against = plugins
+                else:
+                    check_against = themes
+
+                assert call[0][0].rstrip() == check_against[i % 3]
+
+    def test_ss_calls_modules_get(self):
+        ss = SilverStripe()
+        o = mock_open()
+
+        with patch('plugins.update.open', o, create=True):
+            with patch('common.update_api.modules_get') as p:
+                self.updater.update_plugins(SilverStripe(), "Drupal")
+                assert p.called
+
+    def _mod_ss_modules_mock(self,):
+        do_resp = codecs.open('tests/resources/silverstripe_org_response.html', encoding='utf-8').read()
+        do_resp_last = codecs.open('tests/resources/silverstripe_org_response_partial.html').read()
+        ss_modules_file = open('tests/resources/silverstripe_modules.json').read()
+        packagist_with_installer = open('tests/resources/packagist_org_with_installer.json').read()
+        packagist_without_installer = open('tests/resources/packagist_org_without_installer.json').read()
+
+        responses.add(responses.GET, 'http://addons.silverstripe.org/add-ons?search=&type=module&sort=downloads&start=0',
+                body=do_resp, match_querystring=True)
+        responses.add(responses.GET, 'http://addons.silverstripe.org/add-ons?search=&type=module&sort=downloads&start=16',
+                body=do_resp, match_querystring=True)
+        responses.add(responses.GET, 'http://addons.silverstripe.org/add-ons?search=&type=module&sort=downloads&start=32',
+                body=do_resp_last, match_querystring=True)
+
+        responses.add(responses.GET, 'http://addons.silverstripe.org/add-ons?search=&type=theme&sort=downloads&start=0',
+                body=do_resp, match_querystring=True)
+        responses.add(responses.GET, 'http://addons.silverstripe.org/add-ons?search=&type=theme&sort=downloads&start=16',
+                body=do_resp_last, match_querystring=True)
+
+        ss_modules = json.loads(ss_modules_file)
+        base_url = 'http://packagist.org/p/%s.json'
+        for mod in ss_modules:
+            url = base_url % mod
+            if mod == "ajshort/silverstripe-gridfieldextensions":
+                responses.add(responses.GET, url,
+                        body=packagist_with_installer)
+            else:
+                responses.add(responses.GET, url,
+                        body=packagist_without_installer)
+
+    def test_ss_calls_modules_get_proper(self):
+        self._mod_ss_modules_mock()
+
+        ss = SilverStripe()
+        o = mock_open()
+        plugins, themes = ss.update_plugins()
+
+        # verify removes duplicates.
+        assert len(plugins) == 18
+        # verifies package -> folder conversion.
+        assert 'gridfieldextensions' in plugins
+        assert len(themes) == 18
+        assert 'gridfieldextensions' in themes
